/**
 * @file
 * VuoHeap interface.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VUOHEAP_H
#define VUOHEAP_H

#include <stdlib.h>
#include <stdbool.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * A type for destructor functions, such as @c free(void *), which are used to deallocate reference-counted
 * memory when it's no longer in use.
 */
typedef void (*DeallocateFunctionType)(void *);

void initializeReferenceCounts(void);
void finalizeReferenceCounts(void);

int vuoRegister(const void *heapPointer, DeallocateFunctionType deallocate);
int vuoRetain(const void *heapPointer);
int vuoRelease(const void *heapPointer);

#ifdef __cplusplus
}
#endif

#endif
