/**
 * @file
 * VuoTransform C type definition.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VUOTRANSFORM_H
#define VUOTRANSFORM_H

#include "VuoPoint3d.h"

/**
 * @ingroup VuoTypes
 * @defgroup VuoTransform VuoTransform
 * A 3D transformation (scale, rotation, translation).
 *
 * @{
 */

/**
 * A 3D transformation (scale, rotation, translation).
 *
 * Instead of a precalculated 4x4 matrix, it's stored as separate operations
 * in order to [minimize drift](http://bitsquid.blogspot.com/2012/07/matrices-rotation-scale-and-drifting.html).
 */
typedef struct
{
	VuoPoint3d translation;
	float rotation[9]; ///< Column-major 3x3 matrix
	VuoPoint3d scale;
} VuoTransform;

void VuoTransform_getMatrix(const VuoTransform value, float *matrix);
VuoTransform VuoTransform_makeEuler(VuoPoint3d translation, VuoPoint3d rotation, VuoPoint3d scale);

VuoTransform VuoTransform_valueFromString(const char * initializer);
char * VuoTransform_stringFromValue(const VuoTransform value);
char * VuoTransform_summaryFromValue(const VuoTransform value);

/**
 * @}
 */

#endif
